@@ -1,9 +1,9 @@
 # -*-cperl-*-
 #
 # Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
-# Copyright (c) 2016 Ashish Gulhati <biz-btc at ashish dot neomailbox.com>
+# Copyright (c) 2016 Ashish Gulhati <biz-btc at hash dot neomailbox.ch>
 #
-# $Id: lib/Business/Bitcoin.pm v1.017 Wed Jan 11 00:21:59 EST 2017 $
+# $Id: lib/Business/Bitcoin.pm v1.020 Thu Jan 19 11:59:25 PST 2017 $
 
 use strict;
 
@@ -18,7 +18,7 @@ use Business::Bitcoin::Request;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.017 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.020 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -47,7 +47,7 @@ sub new {
       return undef;
     }
   }
-  bless { XPUB => $args{XPUB}, DB => $db, KUCMD => $args{kucmd} || '/usr/local/bin/ku' }, $class;
+  bless { XPUB => $args{XPUB}, DB => $db }, $class;
 }
 
 sub request {                      # Create a Bitcoin payment request
@@ -69,10 +69,10 @@ sub findreq {                      # Retrieve a previously created request
 sub AUTOLOAD {
   my $self = shift; (my $auto = $AUTOLOAD) =~ s/.*:://;
   return if $auto eq 'DESTROY';
-  if ($auto =~ /^(xpub|db|kucmd)$/x) {
+  if ($auto =~ /^(xpub|db)$/x) {
     $self->{"\U$auto"} = shift if (defined $_[0]);
   }
-  if ($auto =~ /^(xpub|db|version|kucmd)$/x) {  
+  if ($auto =~ /^(xpub|db|version)$/x) {  
     return $self->{"\U$auto"};
   }
   else {
@@ -82,14 +82,16 @@ sub AUTOLOAD {
 
 1; # End of Business::Bitcoin
 
+__END__
+
 =head1 NAME
 
 Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 
 =head1 VERSION
 
- $Revision: 1.017 $
- $Date: Wed Jan 11 00:21:59 EST 2017 $
+ $Revision: 1.020 $
+ $Date: Thu Jan 19 11:59:25 PST 2017 $
 
 =head1 SYNOPSIS
 
@@ -166,8 +168,6 @@ requests table is being used; in that case the index is generated by the
 database. By default, receiving addresses will be generated starting
 from the first one, at index 0.
 
-kucmd - The filename of the "ku" command from pycoin. Default is '/usr/local/bin/ku'.
-
 =back
 
 =head2 request
@@ -233,23 +233,12 @@ The filename of the requests DB file.
 
 The master public key from which all receiving keys are generated.
 
-=head2 kucmd
-
-The pathname of the "ku" command from pycoin.
-
 =head2 version
 
 The version number of this module. Read only.
 
 =head1 PREREQUISITES
 
-=head2 pycoin
-
-The "ku" command from pycoin is used to generate new receiving
-addresses. You can get pycoin from:
-
-    https://github.com/richardkiss/pycoin
-
 =head2 DBD::SQLite
 
 Used to keep track of payment requests.
@@ -261,7 +250,7 @@ blockchain.info API.
 
 =head1 AUTHOR
 
-Ashish Gulhati, C<< <biz-btc at ashish dot neomailbox.com> >>
+Ashish Gulhati, C<< <biz-btc at hash dot neomailbox.ch> >>
 
 =head1 BUGS
 
@@ -299,7 +288,7 @@ L<http://search.cpan.org/dist/Business-Bitcoin/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2016 Ashish Gulhati. All rights reserved.
+Copyright (c) 2016-2017 Ashish Gulhati. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
